Function to install the Stockfish chess engine under Windows.

install_stockfish()

Details

The trainer can make use of the Stockfish chess engine to obtain position evaluations and for the play mode to play against the engine. The present function installs Stockfish automatically for you. When running the trainer, it will then automatically detect this installation and make use of it.

Note that this function only works under Windows. Under macOS and Linux, you can download and install Stockfish from https://stockfishchess.org/download/ or obtain it via your operating system package manager.

Value

The function does not return an object.

Author

Wolfgang Viechtbauer (wvb@wvbauer.com)

Examples

if (FALSE) { # \dontrun{
install_stockfish()
} # }