install_mpg123.RdFunction to install the mpg123 player under Windows.
install_mpg123()The trainer plays various sounds (e.g., when playing moves, when capturing pieces, when making a wrong move, when completing a sequence). See the playsound function for further details.
Windows does not provide a simple way to play sound files from the command line by default. To make sounds work under Windows, one can use the lightweight and open-source mpg123 player from https://www.mpg123.de. The present function installs the player automatically for you.
The function does not return an object.
if (FALSE) { # \dontrun{
install_mpg123()
} # }